@@ -1,8 +1,8 @@
-from django.views.decorators.csrf import csrf_exempt
+from django.views.decorators.csrf import csrf_exempt, csrf_protect
 from cached_hitcount.settings import CACHED_HITCOUNT_CSRF_EXEMPT
 
 def conditional_csrf_exempt(func):
-    if not CACHED_HITCOUNT_CSRF_EXEMPT:
+    if CACHED_HITCOUNT_CSRF_EXEMPT:
         return csrf_exempt(func)
     else:
-        return func
\ No newline at end of file
+        return csrf_protect(func)
\ No newline at end of file
