@@ -11,4 +11,6 @@ CACHED_HITCOUNT_IP_CACHE = getattr(settings, 'HITCOUNT_IP_CACHE', 'hitcount__bla
 CACHED_HITCOUNT_LOCK_KEY = getattr(settings, 'HITCOUNT_LOCK_KEY', 'hitcountlock')#key name to use for locking when persisting hits to DB
 CACHED_HITCOUNT_EXCLUDE_IP_ADDRESS = getattr(settings, 'HITCOUNT_EXCLUDE_IP_ADDRESS', True)#Wheter or not you want to exclude some ip addresses
 CACHED_HITCOUNT_EXCLUDE_BOTS = getattr(settings, 'HITCOUNT_EXCLUDE_BOTS', True)#Whether or not you exclude bots
-CACHED_HITCOUNT_CSRF_EXEMPT = getattr(settings, 'HITCOUNT_CSRF_EXEMPT', False)#Whether or not ajax view is CSRF exempt by default
\ No newline at end of file
+CACHED_HITCOUNT_CSRF_EXEMPT = getattr(settings, 'HITCOUNT_CSRF_EXEMPT', False)#Whether or not ajax view is CSRF exempt by default
+CACHED_HITCOUNT_SERVER_CALLBACKS = getattr(settings, 'HITCOUNT_SERVER_CALLBACKS', False)#Dict with with value as tuple of module and method to call on server. (default is {})
+CACHED_HITCOUNT_CLIENT_CALLBACKS = getattr(settings, 'HITCOUNT_CLIENT_CALLBACKS', False)#List of Javascript functions to call when response is received. Response is passed to these functions. (default is [])
\ No newline at end of file
